//---------------------------------------------------------------------
//
//							 Software License Agreement
//
// The software supplied herewith by Microchip Technology Incorporated 
// (the Company) for its PICmicro Microcontroller is intended and 
// supplied to you, the Companys customer, for use solely and 
// exclusively on Microchip PICmicro Microcontroller products. The 
// software is owned by the Company and/or its supplier, and is 
// protected under applicable copyright laws. All rights are reserved. 
//  Any use in violation of the foregoing restrictions may subject the 
// user to criminal sanctions under applicable laws, as well as to 
// civil liability for the breach of the terms and conditions of this 
// license.
//
// THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES, 
// WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
// TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
// PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT, 
// IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR 
// CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
//
//---------------------------------------------------------------------
//	File:		BlinkLEDs.c
//
//	Written By: Jorge Zambada, Microchip Technology
//						
// 
// The following files should be included in the MPLAB project:
//
//		BlinkLEDs.c  -- Main source code file
//		p30f3010.gld -- Linker script file
//				
// CONFIGURATION FUSE INSTRUCTIONS:
// Osc MODE: XT w/PLL 8X
// WDT: disabled
// Comm Channel Select: Use EMUC2 and EMUD2
//---------------------------------------------------------------------
//
// Revision History
//
// 6/19/05 -- first version 
// 7/05/05 -- second version 
//---------------------------------------------------------------------- 
//
// Lab 1 is the starting lab for Motor Control Workshop in a Box.
// This lab shows users how to use the PICDEM MCLV board for
// programming and running code written for a dsPIC
// To program the part the user must move the DIP switch on the 
// MCLV board to PRGM.  Once programmed the user must move the 
// DIP switch to DEBUG and then run in Debug mode using ICD 2.
// The LEDs named: PWM0, PWM2 and PWM4 should be blinking at a 1 Hz rate
// 

#include "p30f3010.h"

#define FCY  10000000			// use PLL 8X
#define MILLISEC FCY/10000		// 1 mSec delay constant
#define S2 PORTCbits.RC14		// port input for S2

void InitTMR1(void);			// Periodic Interrupts to toggle pins
void DelayNmSec(unsigned int N);// General 1 ms subroutine

void __attribute__((__interrupt__)) _T1Interrupt(void)
{
	IFS0bits.T1IF = 0;			// Clear Timer Flag
	OVDCON ^= 0x0015;			// Toggle Pins PWM0, PWM2, PWM4
	return;		
}

int main(void)	
{
	ADPCFG = 0xFFF8;			// all PORTB = Digital;RB0 to RB2 = analog
	PWMCON1 = 0x0F77;			// Enable PWM Pins
	PTCONbits.PTEN = 1;			// Enable PWM
	InitTMR1();					// Initialize Timer 1 for periodic ISRs
	while(1)
	{
		OVDCON = 0x0000;		// Turn OFF all LEDs
		while (S2);				// wait till S2 is pressed 
		DelayNmSec(30);			// -- do --
		while (!S2);			// if pressed wait till S2 is released
		DelayNmSec(30);			// -- do --
		T1CONbits.TON = 1;		// turn on T1
		while (S2);				// wait till S2 is pressed 
		DelayNmSec(30);			// -- do --
		while (!S2);			// if pressed wait till S2 is released
		DelayNmSec(30);			// -- do --
		T1CONbits.TON = 0;		// turn on T1
	}
	return;
}

//---------------------------------------------------------------------
// This is a generic 1ms delay routine to give a 1mS to 65.5 Seconds delay
// For N = 1 the delay is 1 mS, for N = 65535 the delay is 65,535 mS. 
// Note that FCY is used in the computation.  Please make the necessary
// Changes(PLLx4 or PLLx8 etc) to compute the right FCY as in the define
// statement above.

void DelayNmSec(unsigned int N)
{
	unsigned int j;
	while(N--)
	 	for(j=0;j < MILLISEC;j++);
	return;
}

//---------------------------------------------------------------------
// This subroutine will initialize the Timer 1 for periodic interrupts. In
// the ISRs the LEDs PWM0, PWM2 and PWM4 will be toggled.

void InitTMR1(void)
{
	TMR1 = 0x0000;			// clr tmr1
	PR1 = 19531;			// period for 500 mS
	T1CON = 0x0030;			// 1:256 Prescale Value
	IFS0bits.T1IF = 0;		//clear interrupt flag
	IEC0bits.T1IE = 1;		// enable T1 interrutps
	return;
}

