#include "SineGen.h"
#include <p30fxxxx.h>

#define _0_DEGREES 0x0000    // Offset for Phase B (0 electrical degrees)
#define _120_DEGREES 0x5555  // Offset for Phase A (120 electrical degrees)
#define _240_DEGREES 0xAAAA  // Offset for Phase C (240 electrical degrees)

int sinetable[64] = 
{0,2782,5536,8237,10859,13376,15765,18002,20065,21935,
23594,25026,26216,27154,27831,28239,28376,28239,27831,27154,
26216,25026,23594,21935,20065,18002,15765,13376,10859,8237,
5536,2782,0,-2782,-5536,-8237,-10859,-13376,-15765,-18002,
-20065,-21935,-23594,-25026,-26216,-27154,-27831,-28239,-28376,-28239,
-27831,-27154,-26216,-25026,-23594,-21935,-20065,-18002,-15765,-13376,
-10859,-8237,-5536,-2782};

unsigned int Phase_Offset; // Offset added to the pointer to get Phase B and C
int Multiplier;            // Variable used for scaling the table down to the
                           // proper valued of the PWM period register
int Result;                // Temporal variable used by the assembly code.
int Mod_Index;

void SineGen (int _volts, unsigned int _angle)
{
	PWMCON2bits.UDIS = 1;

	Mod_Index = _volts;

	Phase_Offset = _0_DEGREES; // Add offset for Phase B
	Multiplier = sinetable[(_angle + Phase_Offset) >> 10]; // Get a new value from table
    ScaleSineData();	// Scale the value read using fractional multiplication
	PDC2 = Result + PTPER;    // Update Phase B duty cycle register

	Phase_Offset = _120_DEGREES; // Add offset for Phase A
	Multiplier = sinetable[(_angle + Phase_Offset) >> 10]; // Get a new value from table
	ScaleSineData();    // Scale the value read using fractional multiplication
	PDC1 = Result + PTPER;    // Update Phase A duty cycle register

	Phase_Offset = _240_DEGREES; // Add offset for Phase C
	Multiplier = sinetable[(_angle + Phase_Offset) >> 10]; // Get a new value from table
	ScaleSineData();    // Scale the value read using fractional multiplication
	PDC3 = Result + PTPER;    // Update Phase C duty cycle register

	PWMCON2bits.UDIS = 0;
	return;
}
