; WARRANTY OF ANY KIND, WHETHER EXPRESS OR IMPLIED, INCLUDING BUT NOT
; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
; PARTICULAR PURPOSE, OR NON-INFRINGEMENT. IN NO EVENT SHALL MICROCHIP
; BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR CONSEQUENTIAL
; DAMAGES, LOST PROFITS OR LOST DATA, HARM TO YOUR EQUIPMENT, COST OF
; PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR SERVICES, ANY CLAIMS
; BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF),
; ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION, OR OTHER SIMILAR COSTS.
;
; REVISION HISTORY:
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; Author            Date      Comments on this revision
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; First Last Name   mm/dd/yy  Place your comments here
; Jorge Zambada     08/17/05  Assembly functions for WIB
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.include "p30f3010.inc"

	.global _SpeedCalculation
	.global _SpeedControl
	.global _Phase_Adv_Profile

;********************************************************************
; This subroutine Calculates the speed of the BLDC motor in fractional
; format using Fractional Division as follows:
;
;                                        Minimum Period
;   Actual Speed = (Fractinal Division) -----------------
;                                        Actual Period
;
;********************************************************************

_SpeedCalculation:
	MOV __MINPERIOD, W8
	MOV _Period, W9
	REPEAT #17
	DIVF W8, W9
	MOV W0, _Speed
	RETURN

;********************************************************************
;   This subroutine will calculate a timer value to commutate in advance.
;   The value calculated will depend on the motor actual speed, so that the more
;   Speed we have, the more phase advance we generate, up to 60 Degrees of Advance
;
;                   |Actual Speed| - Minimum_Speed_Ph_Adv
;   Timer Value = ----------------------------------------- x (60 Deg Time)
;                            |Actual Speed|
;
;*********************************************************************

_Phase_Adv_Profile:
	BSET CORCON, #SATA ; Enable Saturation on Acc A
	MOV #PR2, W3
	MOV _Phase_Advance_Perc_Dividend, W8
	MOV _Phase_Advance_Perc_Divisor, W9
	REPEAT #17
	DIVF W8, W9
	MOV W0, W4
	MOV _Phase_Advance_Value, W5
	LAC W5, A	
	MSC W4*W5, A
	SAC A, [W3]
	BCLR CORCON, #SATA ; Disable Saturation on Acc A
	RETURN

.end
